% Figure 1: Arenal data
%
% Random Spectral Sampling Toolbox - Roel Snieder and Michael B. Wakin
% Version 1.0 - March 23, 2022
% See README.txt


clear all; close all;
load Dec_Arenal
N = length(data);

% Original pressure recorded at Arenal after tapering and adding zeros 
% (See preprocessArenalData.m for the origin of this data.)
Arenal_org = data;

% Periodic subsampling in the frequency domain with a factor of 2
Arenal_spectrum = fft(Arenal_org);
Arenal_spectrum(2:2:end) = 0;
Arenal_per = 2*real(ifft(Arenal_spectrum));

% Randomly subsample spectrum by factor of 2 without replacement
Arenal_rand = real(subsampleSpectrum(Arenal_org,N/2,1));

% Create figure
figure(1); clf;
offset = 2;
set(gcf,'color','white');
box on
plot(time,Arenal_org,'k')
hold on
plot(time,offset + Arenal_per,'r')
plot(time,2*offset + Arenal_rand,'b')
axis( [0 400 -1  5]);
xlabel('time (s)','FontSize',18);
set(gca,'xTick',0:50:350,'FontSize',18)
set(gca,'yTick',-100:1000:1000,'FontSize',18)
text(330,0.3,'original','FontSize',18)
text(330,2.7,'periodic','FontSize',18)
text(330,4.4,'random','FontSize',18)
% print('fig1','-dpng')

