% Figure 2: Delta function
%
% Random Spectral Sampling Toolbox - Roel Snieder and Michael B. Wakin
% Version 1.0 - March 23, 2022
% See README.txt

clear all; close all;
N = 600;

% Construct delta function in time domain
delta = zeros(N,1);
delta(N/2+1) = 1;

% Randomly subsample spectrum by factor of 3 without replacement
delta_rand = subsampleSpectrum(delta,N/3,1);

% Time indices
t = [-N/2:N/2-1]';

% Create figure
figure(2); clf;
set(gcf,'color','white')
box on
plot(t,real(delta_rand),'b','LineWidth',2)
hold on
plot(t,imag(delta_rand),'r','LineWidth',2)
axis( [-300 300 -0.2 1.05]);
xlabel('time (s)','FontSize',18);
set(gca,'xTick',-200:100:200,'FontSize',18)
set(gca,'yTick',-0:0.2:1,'FontSize',18)
legend('real part','imaginary part','FontSize',18)
% print('fig2','-dpng')

% Compute standard deviation of estimation error
sigma = sqrt(sum(abs(delta-delta_rand).^2)/(N-1))
