% Taper the pressure signal recorded at Arenal after tapering and add zeros 
%
% This data was used for Figure 1 of: 
% Snieder, R. and M. Hagerty, Monitoring change in Volcanic Interiors using 
% Coda Wave Interferometry: Application to Arenal Volcano, Costa Rica, 
% Geophys. Res. Lett., 31, L09608, doi:10.1029/2004GL019670,  2004.
%
% Random Spectral Sampling Toolbox - Roel Snieder and Michael B. Wakin
% Version 1.0 - March 23, 2022
% See README.txt


clear all;

% Load data from Snieder and Hagerty paper
load Org_Arenal.mat

% Taper over 2000 samples at the beggining and the end
nstart = 13000;
nend = 25001;
ncut = nend-nstart+1;
nzeros = 2000;
dec = pres(nstart:nend);
taper = tukeywin(ncut,2*2000/ncut);
dat = taper.*dec;

% Add zeros at the begin and end
data(1:nzeros)=0;
data(nzeros+1:nzeros+ncut)=dat;
data(nzeros+ncut+1:nzeros+ncut+nzeros)=0;
nsam = 2*nzeros+ncut;
t0 = 0;
time = t0 + (0:nsam-1)*dt;

% save time and data
save('Dec_Arenal2.mat','time','data','dt','nsam');